@@ -46,32 +46,36 @@ class NBApi(FastAPI):
         self.get('/metrics', include_in_schema=False)(metrics)
 
         async def handle_httperror(rec: Request, exc: StarletteHTTPException):
+            logging.error(exc)
             return JSONResponse(
-                status_code=200,
+                status_code=exc.status_code,
                 content=jsonable_encoder(
                     {'status': 'failed', 'code': f'{exc.status_code}'}),
             )
         self.exception_handler(StarletteHTTPException)(handle_httperror)
 
         async def auth_error(rec: Request, exc: AuthError):
+            logging.error(exc)
             return JSONResponse(
-                status_code=200,
+                status_code=401,
                 content=jsonable_encoder(
                     {'status': 'failed', 'code': '401'}),
             )
         self.exception_handler(AuthError)(auth_error)
 
         async def handle_valueerror(rec: Request, exc: ValueError):
+            logging.error(exc)
             return JSONResponse(
-                status_code=200,
+                status_code=400,
                 content=jsonable_encoder(
                     {'status': 'failed', 'code': '400'}),
             )
         self.exception_handler(ValueError)(handle_valueerror)
 
         async def handle_exception(rec: Request, exc: Exception):
+            logging.error(exc)
             return JSONResponse(
-                status_code=200,
+                status_code=500,
                 content=jsonable_encoder(
                     {'status': 'failed', 'code': '500', 'msg': f'{str(exc)}'}),
             )
